histomicstk.saliency
======================

.. automodule:: histomicstk.saliency
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::
    :maxdepth: 1

    Tissue detection <histomicstk.saliency.tissue_detection.rst>
    Cellularity detection (using thresholding) <histomicstk.saliency.cellularity_detection_thresholding.rst>
    Cellularity detection (using superpixels) <histomicstk.saliency.cellularity_detection_superpixels.rst>
